@@ -33,7 +33,7 @@ if (echo "$DDCPROBE" | egrep "(edidfail|ddcfail)" >/dev/null 2>&1); then
   exit 0
 fi
 
-if (echo "$DDCPROBE" | egrep "^input: digital"); then
+if (echo "$DDCPROBE" | egrep "^input: .*digital"); then
   SCREENTYPE="lcd"
 else
   SCREENTYPE="crt"
